@@ -2,7 +2,7 @@ use strict;
 use warnings;
 package YAML::PP::Common;
 
-our $VERSION = '0.023_001'; # TRIAL VERSION
+our $VERSION = '0.023_002'; # TRIAL VERSION
 
 use base 'Exporter';
 
@@ -18,7 +18,7 @@ our @EXPORT_OK = qw/
     YAML_ANY_MAPPING_STYLE
     YAML_BLOCK_MAPPING_STYLE YAML_FLOW_MAPPING_STYLE
 
-    PRESERVE_ALL PRESERVE_ORDER PRESERVE_SCALAR_STYLE
+    PRESERVE_ALL PRESERVE_ORDER PRESERVE_SCALAR_STYLE PRESERVE_FLOW_STYLE
 /;
 
 use constant {
@@ -41,6 +41,7 @@ use constant {
     PRESERVE_ALL          => 1,
     PRESERVE_ORDER        => 2,
     PRESERVE_SCALAR_STYLE => 4,
+    PRESERVE_FLOW_STYLE   => 8,
 };
 
 my %scalar_style_to_string = (
